==> zio-aws-datasync_2.13-7.21.15.9-sources.jar: zio/aws/datasync/model/Latency.scala <==
package zio.aws.datasync.model
import zio.aws.datasync.model.primitives.NonNegativeDouble
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class Latency(
    read: Optional[NonNegativeDouble] = Optional.Absent,
    write: Optional[NonNegativeDouble] = Optional.Absent,
    other: Optional[NonNegativeDouble] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datasync.model.Latency = {
    import Latency.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datasync.model.Latency
      .builder()
      .optionallyWith(
        read.map(value => NonNegativeDouble.unwrap(value): java.lang.Double)
      )(_.read)
      .optionallyWith(
        write.map(value => NonNegativeDouble.unwrap(value): java.lang.Double)
      )(_.write)
      .optionallyWith(
        other.map(value => NonNegativeDouble.unwrap(value): java.lang.Double)
      )(_.other)
      .build()
  }
  def asReadOnly: zio.aws.datasync.model.Latency.ReadOnly =
    zio.aws.datasync.model.Latency.wrap(buildAwsValue())
}
object Latency {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.datasync.model.Latency] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datasync.model.Latency =
      zio.aws.datasync.model.Latency(
        read.map(value => value),
        write.map(value => value),
        other.map(value => value)
      )
    def read: Optional[NonNegativeDouble]
    def write: Optional[NonNegativeDouble]
    def other: Optional[NonNegativeDouble]
    def getRead: ZIO[Any, AwsError, NonNegativeDouble] =
      AwsError.unwrapOptionField("read", read)
    def getWrite: ZIO[Any, AwsError, NonNegativeDouble] =
      AwsError.unwrapOptionField("write", write)
    def getOther: ZIO[Any, AwsError, NonNegativeDouble] =
      AwsError.unwrapOptionField("other", other)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datasync.model.Latency
  ) extends zio.aws.datasync.model.Latency.ReadOnly {
    override val read: Optional[NonNegativeDouble] = zio.aws.core.internal
      .optionalFromNullable(impl.read())
      .map(value => zio.aws.datasync.model.primitives.NonNegativeDouble(value))
    override val write: Optional[NonNegativeDouble] = zio.aws.core.internal
      .optionalFromNullable(impl.write())
      .map(value => zio.aws.datasync.model.primitives.NonNegativeDouble(value))
    override val other: Optional[NonNegativeDouble] = zio.aws.core.internal
      .optionalFromNullable(impl.other())
      .map(value => zio.aws.datasync.model.primitives.NonNegativeDouble(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.datasync.model.Latency
  ): zio.aws.datasync.model.Latency.ReadOnly = new Wrapper(impl)
}

==> zio-aws-datasync_3-7.21.15.3-sources.jar: zio/aws/datasync/model/Latency.scala <==
package zio.aws.datasync.model
import zio.aws.datasync.model.primitives.NonNegativeDouble
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class Latency(
    read: Optional[NonNegativeDouble] = Optional.Absent,
    write: Optional[NonNegativeDouble] = Optional.Absent,
    other: Optional[NonNegativeDouble] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datasync.model.Latency = {
    import Latency.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datasync.model.Latency
      .builder()
      .optionallyWith(
        read.map(value => NonNegativeDouble.unwrap(value): java.lang.Double)
      )(_.read)
      .optionallyWith(
        write.map(value => NonNegativeDouble.unwrap(value): java.lang.Double)
      )(_.write)
      .optionallyWith(
        other.map(value => NonNegativeDouble.unwrap(value): java.lang.Double)
      )(_.other)
      .build()
  }
  def asReadOnly: zio.aws.datasync.model.Latency.ReadOnly =
    zio.aws.datasync.model.Latency.wrap(buildAwsValue())
}
object Latency {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.datasync.model.Latency] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datasync.model.Latency =
      zio.aws.datasync.model.Latency(
        read.map(value => value),
        write.map(value => value),
        other.map(value => value)
      )
    def read: Optional[NonNegativeDouble]
    def write: Optional[NonNegativeDouble]
    def other: Optional[NonNegativeDouble]
    def getRead: ZIO[Any, AwsError, NonNegativeDouble] =
      AwsError.unwrapOptionField("read", read)
    def getWrite: ZIO[Any, AwsError, NonNegativeDouble] =
      AwsError.unwrapOptionField("write", write)
    def getOther: ZIO[Any, AwsError, NonNegativeDouble] =
      AwsError.unwrapOptionField("other", other)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datasync.model.Latency
  ) extends zio.aws.datasync.model.Latency.ReadOnly {
    override val read: Optional[NonNegativeDouble] = zio.aws.core.internal
      .optionalFromNullable(impl.read())
      .map(value => zio.aws.datasync.model.primitives.NonNegativeDouble(value))
    override val write: Optional[NonNegativeDouble] = zio.aws.core.internal
      .optionalFromNullable(impl.write())
      .map(value => zio.aws.datasync.model.primitives.NonNegativeDouble(value))
    override val other: Optional[NonNegativeDouble] = zio.aws.core.internal
      .optionalFromNullable(impl.other())
      .map(value => zio.aws.datasync.model.primitives.NonNegativeDouble(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.datasync.model.Latency
  ): zio.aws.datasync.model.Latency.ReadOnly = new Wrapper(impl)
}
